package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.ShareInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.ShareInfoMapper;
import com.ruoyi.system.service.IShareInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-19
 */
@Service
public class ShareInfoServiceImpl implements IShareInfoService 
{
    @Autowired
    private ShareInfoMapper shareInfoMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public ShareInfo selectShareInfoById(String id)
    {
        return shareInfoMapper.selectShareInfoById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param shareInfo 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<ShareInfo> selectShareInfoList(ShareInfo shareInfo)
    {
        return shareInfoMapper.selectShareInfoList(shareInfo);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param shareInfo 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertShareInfo(ShareInfo shareInfo)
    {
        shareInfo.setCreateTime(DateUtils.getNowDate());
        return shareInfoMapper.insertShareInfo(shareInfo);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param shareInfo 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateShareInfo(ShareInfo shareInfo)
    {
        shareInfo.setUpdateTime(DateUtils.getNowDate());
        return shareInfoMapper.updateShareInfo(shareInfo);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteShareInfoByIds(String[] ids)
    {
        return shareInfoMapper.deleteShareInfoByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteShareInfoById(String id)
    {
        return shareInfoMapper.deleteShareInfoById(id);
    }

    @Override
    public List<ShareInfo> findShareInfoListPage(ShareInfo shareInfo) {
        return shareInfoMapper.selectShareInfoListPage(shareInfo);
    }
}
